"""cuvis-ai-schemas: Lightweight schema definitions for the cuvis-ai ecosystem."""

from cuvis_ai_schemas.base import BaseSchemaModel

__version__ = "0.1.0"

__all__ = ["BaseSchemaModel", "__version__"]
