# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cuvis_ai_schemas/grpc/v1/cuvis_ai.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 33, 5, "", "cuvis_ai_schemas/grpc/v1/cuvis_ai.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\'cuvis_ai_schemas/grpc/v1/cuvis_ai.proto\x12\x0b\x63uvis_ai.v1"c\n\x06Tensor\x12\x14\n\x05shape\x18\x01 \x03(\x03R\x05shape\x12(\n\x05\x64type\x18\x02 \x01(\x0e\x32\x12.cuvis_ai.v1.DTypeR\x05\x64type\x12\x19\n\x08raw_data\x18\x03 \x01(\x0cR\x07rawData"\x90\x01\n\x07\x43ontext\x12\x31\n\x05stage\x18\x01 \x01(\x0e\x32\x1b.cuvis_ai.v1.ExecutionStageR\x05stage\x12\x14\n\x05\x65poch\x18\x02 \x01(\x05R\x05\x65poch\x12\x1b\n\tbatch_idx\x18\x03 \x01(\x05R\x08\x62\x61tchIdx\x12\x1f\n\x0bglobal_step\x18\x04 \x01(\x05R\nglobalStep"3\n\x0ePipelineConfig\x12!\n\x0c\x63onfig_bytes\x18\x01 \x01(\x0cR\x0b\x63onfigBytes"/\n\nDataConfig\x12!\n\x0c\x63onfig_bytes\x18\x01 \x01(\x0cR\x0b\x63onfigBytes"4\n\x0fOptimizerConfig\x12!\n\x0c\x63onfig_bytes\x18\x01 \x01(\x0cR\x0b\x63onfigBytes"4\n\x0fSchedulerConfig\x12!\n\x0c\x63onfig_bytes\x18\x01 \x01(\x0cR\x0b\x63onfigBytes"4\n\x0f\x43\x61llbacksConfig\x12!\n\x0c\x63onfig_bytes\x18\x01 \x01(\x0cR\x0b\x63onfigBytes"\xb8\x01\n\x10PipelineMetadata\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x18\n\x07\x63reated\x18\x03 \x01(\tR\x07\x63reated\x12(\n\x10\x63uvis_ai_version\x18\x04 \x01(\tR\x0e\x63uvisAiVersion\x12\x12\n\x04tags\x18\x05 \x03(\tR\x04tags\x12\x16\n\x06\x61uthor\x18\x06 \x01(\tR\x06\x61uthor"\xec\x01\n\x0cPipelineInfo\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04path\x18\x02 \x01(\tR\x04path\x12\x39\n\x08metadata\x18\x03 \x01(\x0b\x32\x1d.cuvis_ai.v1.PipelineMetadataR\x08metadata\x12\x12\n\x04tags\x18\x04 \x03(\tR\x04tags\x12\x1f\n\x0bhas_weights\x18\x05 \x01(\x08R\nhasWeights\x12!\n\x0cweights_path\x18\x06 \x01(\tR\x0bweightsPath\x12!\n\x0cyaml_content\x18\x07 \x01(\tR\x0byamlContent"3\n\x0eTrainingConfig\x12!\n\x0c\x63onfig_bytes\x18\x01 \x01(\x0cR\x0b\x63onfigBytes"3\n\x0eTrainRunConfig\x12!\n\x0c\x63onfig_bytes\x18\x01 \x01(\x0cR\x0b\x63onfigBytes"\x80\x01\n\x0b\x42oundingBox\x12\x1d\n\nelement_id\x18\x01 \x01(\x05R\telementId\x12\x13\n\x05x_min\x18\x02 \x01(\x02R\x04xMin\x12\x13\n\x05y_min\x18\x03 \x01(\x02R\x04yMin\x12\x13\n\x05x_max\x18\x04 \x01(\x02R\x04xMax\x12\x13\n\x05y_max\x18\x05 \x01(\x02R\x04yMax"?\n\rBoundingBoxes\x12.\n\x05\x62oxes\x18\x01 \x03(\x0b\x32\x18.cuvis_ai.v1.BoundingBoxR\x05\x62oxes"n\n\x05Point\x12\x1d\n\nelement_id\x18\x01 \x01(\x05R\telementId\x12\x0c\n\x01x\x18\x02 \x01(\x02R\x01x\x12\x0c\n\x01y\x18\x03 \x01(\x02R\x01y\x12*\n\x04type\x18\x04 \x01(\x0e\x32\x16.cuvis_ai.v1.PointTypeR\x04type"4\n\x06Points\x12*\n\x06points\x18\x01 \x03(\x0b\x32\x12.cuvis_ai.v1.PointR\x06points"\xb9\x03\n\nInputBatch\x12\x35\n\x0bwavelengths\x18\x01 \x01(\x0b\x32\x13.cuvis_ai.v1.TensorR\x0bwavelengths\x12\'\n\x04\x63ube\x18\x02 \x01(\x0b\x32\x13.cuvis_ai.v1.TensorR\x04\x63ube\x12\'\n\x04mask\x18\x03 \x01(\x0b\x32\x13.cuvis_ai.v1.TensorR\x04mask\x12\x32\n\x06\x62\x62oxes\x18\x04 \x01(\x0b\x32\x1a.cuvis_ai.v1.BoundingBoxesR\x06\x62\x62oxes\x12+\n\x06points\x18\x05 \x01(\x0b\x32\x13.cuvis_ai.v1.PointsR\x06points\x12\x1f\n\x0btext_prompt\x18\x06 \x01(\tR\ntextPrompt\x12K\n\x0c\x65xtra_inputs\x18\x07 \x03(\x0b\x32(.cuvis_ai.v1.InputBatch.ExtraInputsEntryR\x0b\x65xtraInputs\x1aS\n\x10\x45xtraInputsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x13.cuvis_ai.v1.TensorR\x05value:\x02\x38\x01"|\n\nTensorSpec\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05shape\x18\x02 \x03(\x03R\x05shape\x12(\n\x05\x64type\x18\x03 \x01(\x0e\x32\x12.cuvis_ai.v1.DTypeR\x05\x64type\x12\x1a\n\x08required\x18\x04 \x01(\x08R\x08required"\x85\x03\n\rTrainResponse\x12.\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x14.cuvis_ai.v1.ContextR\x07\x63ontext\x12>\n\x06losses\x18\x02 \x03(\x0b\x32&.cuvis_ai.v1.TrainResponse.LossesEntryR\x06losses\x12\x41\n\x07metrics\x18\x03 \x03(\x0b\x32\'.cuvis_ai.v1.TrainResponse.MetricsEntryR\x07metrics\x12\x30\n\x06status\x18\x04 \x01(\x0e\x32\x18.cuvis_ai.v1.TrainStatusR\x06status\x12\x18\n\x07message\x18\x05 \x01(\tR\x07message\x1a\x39\n\x0bLossesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x02R\x05value:\x02\x38\x01\x1a:\n\x0cMetricsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x02R\x05value:\x02\x38\x01"\xb6\x01\n\tParamSpec\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x1a\n\x08required\x18\x03 \x01(\x08R\x08required\x12#\n\rdefault_value\x18\x04 \x01(\tR\x0c\x64\x65\x66\x61ultValue\x12 \n\x0b\x64\x65scription\x18\x05 \x01(\tR\x0b\x64\x65scription\x12\x1e\n\nvalidation\x18\x06 \x01(\tR\nvalidation"\x80\x01\n\x10\x43\x61llbackTypeInfo\x12\x12\n\x04type\x18\x01 \x01(\tR\x04type\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x36\n\nparameters\x18\x03 \x03(\x0b\x32\x16.cuvis_ai.v1.ParamSpecR\nparameters"O\n\x15OptimizerParamsSchema\x12\x36\n\nparameters\x18\x01 \x03(\x0b\x32\x16.cuvis_ai.v1.ParamSpecR\nparameters"O\n\x15SchedulerParamsSchema\x12\x36\n\nparameters\x18\x01 \x03(\x0b\x32\x16.cuvis_ai.v1.ParamSpecR\nparameters"R\n\x1dListAvailablePipelinesRequest\x12"\n\nfilter_tag\x18\x01 \x01(\tH\x00R\tfilterTag\x88\x01\x01\x42\r\n\x0b_filter_tag"Y\n\x1eListAvailablePipelinesResponse\x12\x37\n\tpipelines\x18\x01 \x03(\x0b\x32\x19.cuvis_ai.v1.PipelineInfoR\tpipelines"=\n\x16GetPipelineInfoRequest\x12#\n\rpipeline_name\x18\x01 \x01(\tR\x0cpipelineName"Y\n\x17GetPipelineInfoResponse\x12>\n\rpipeline_info\x18\x01 \x01(\x0b\x32\x19.cuvis_ai.v1.PipelineInfoR\x0cpipelineInfo"\x16\n\x14\x43reateSessionRequest"6\n\x15\x43reateSessionResponse\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId"\x88\x01\n\x1cSetSessionSearchPathsRequest\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId\x12!\n\x0csearch_paths\x18\x02 \x03(\tR\x0bsearchPaths\x12\x1b\n\x06\x61ppend\x18\x03 \x01(\x08H\x00R\x06\x61ppend\x88\x01\x01\x42\t\n\x07_append"\x85\x01\n\x1dSetSessionSearchPathsResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12#\n\rcurrent_paths\x18\x02 \x03(\tR\x0c\x63urrentPaths\x12%\n\x0erejected_paths\x18\x03 \x03(\tR\rrejectedPaths"4\n\x13\x43loseSessionRequest\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId"0\n\x14\x43loseSessionResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success"\x88\x01\n\x14ResolveConfigRequest\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId\x12\x1f\n\x0b\x63onfig_type\x18\x02 \x01(\tR\nconfigType\x12\x12\n\x04path\x18\x03 \x01(\tR\x04path\x12\x1c\n\toverrides\x18\x04 \x03(\tR\toverrides":\n\x15ResolveConfigResponse\x12!\n\x0c\x63onfig_bytes\x18\x01 \x01(\x0cR\x0b\x63onfigBytes"<\n\x19GetParameterSchemaRequest\x12\x1f\n\x0b\x63onfig_type\x18\x01 \x01(\tR\nconfigType"=\n\x1aGetParameterSchemaResponse\x12\x1f\n\x0bjson_schema\x18\x01 \x01(\tR\njsonSchema"[\n\x15ValidateConfigRequest\x12\x1f\n\x0b\x63onfig_type\x18\x01 \x01(\tR\nconfigType\x12!\n\x0c\x63onfig_bytes\x18\x02 \x01(\x0cR\x0b\x63onfigBytes"b\n\x16ValidateConfigResponse\x12\x14\n\x05valid\x18\x01 \x01(\x08R\x05valid\x12\x16\n\x06\x65rrors\x18\x02 \x03(\tR\x06\x65rrors\x12\x1a\n\x08warnings\x18\x03 \x03(\tR\x08warnings"\xc1\x01\n\x1aLoadPipelineWeightsRequest\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId\x12#\n\x0cweights_path\x18\x02 \x01(\tH\x00R\x0bweightsPath\x12%\n\rweights_bytes\x18\x03 \x01(\x0cH\x00R\x0cweightsBytes\x12\x1b\n\x06strict\x18\x04 \x01(\x08H\x01R\x06strict\x88\x01\x01\x42\x10\n\x0eweights_sourceB\t\n\x07_strict"\\\n\x1bLoadPipelineWeightsResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12#\n\rresolved_path\x18\x02 \x01(\tR\x0cresolvedPath"n\n\x18SetTrainRunConfigRequest\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId\x12\x33\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1b.cuvis_ai.v1.TrainRunConfigR\x06\x63onfig"g\n\x19SetTrainRunConfigResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12\x30\n\x14pipeline_from_config\x18\x02 \x01(\x08R\x12pipelineFromConfig"\xd0\x01\n\x0cTrainRequest\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId\x12;\n\x0ctrainer_type\x18\x02 \x01(\x0e\x32\x18.cuvis_ai.v1.TrainerTypeR\x0btrainerType\x12+\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x17.cuvis_ai.v1.DataConfigR\x04\x64\x61ta\x12\x37\n\x08training\x18\x04 \x01(\x0b\x32\x1b.cuvis_ai.v1.TrainingConfigR\x08training"6\n\x15GetTrainStatusRequest\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId"]\n\x16GetTrainStatusResponse\x12\x43\n\x0flatest_progress\x18\x01 \x01(\x0b\x32\x1a.cuvis_ai.v1.TrainResponseR\x0elatestProgress" \n\x1eGetTrainingCapabilitiesRequest"\xf5\x02\n\x1fGetTrainingCapabilitiesResponse\x12\x31\n\x14supported_optimizers\x18\x01 \x03(\tR\x13supportedOptimizers\x12\x31\n\x14supported_schedulers\x18\x02 \x03(\tR\x13supportedSchedulers\x12N\n\x13supported_callbacks\x18\x03 \x03(\x0b\x32\x1d.cuvis_ai.v1.CallbackTypeInfoR\x12supportedCallbacks\x12M\n\x10optimizer_params\x18\x04 \x01(\x0b\x32".cuvis_ai.v1.OptimizerParamsSchemaR\x0foptimizerParams\x12M\n\x10scheduler_params\x18\x05 \x01(\x0b\x32".cuvis_ai.v1.SchedulerParamsSchemaR\x0fschedulerParams"\x94\x01\n\x13SavePipelineRequest\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId\x12#\n\rpipeline_path\x18\x02 \x01(\tR\x0cpipelinePath\x12\x39\n\x08metadata\x18\x03 \x01(\x0b\x32\x1d.cuvis_ai.v1.PipelineMetadataR\x08metadata"x\n\x14SavePipelineResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12#\n\rpipeline_path\x18\x02 \x01(\tR\x0cpipelinePath\x12!\n\x0cweights_path\x18\x03 \x01(\tR\x0bweightsPath"m\n\x13LoadPipelineRequest\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId\x12\x37\n\x08pipeline\x18\x02 \x01(\x0b\x32\x1b.cuvis_ai.v1.PipelineConfigR\x08pipeline"k\n\x14LoadPipelineResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12\x39\n\x08metadata\x18\x02 \x01(\x0b\x32\x1d.cuvis_ai.v1.PipelineMetadataR\x08metadata"|\n\x13SaveTrainRunRequest\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId\x12#\n\rtrainrun_path\x18\x02 \x01(\tR\x0ctrainrunPath\x12!\n\x0csave_weights\x18\x03 \x01(\x08R\x0bsaveWeights"\x9d\x01\n\x14SaveTrainRunResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12#\n\rtrainrun_path\x18\x02 \x01(\tR\x0ctrainrunPath\x12#\n\rpipeline_path\x18\x03 \x01(\tR\x0cpipelinePath\x12!\n\x0cweights_path\x18\x04 \x01(\tR\x0bweightsPath"\x9e\x01\n\x16RestoreTrainRunRequest\x12#\n\rtrainrun_path\x18\x01 \x01(\tR\x0ctrainrunPath\x12&\n\x0cweights_path\x18\x02 \x01(\tH\x00R\x0bweightsPath\x88\x01\x01\x12\x1b\n\x06strict\x18\x03 \x01(\x08H\x01R\x06strict\x88\x01\x01\x42\x0f\n\r_weights_pathB\t\n\x07_strict"q\n\x17RestoreTrainRunResponse\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId\x12\x37\n\x08trainrun\x18\x02 \x01(\x0b\x32\x1b.cuvis_ai.v1.TrainRunConfigR\x08trainrun"9\n\x18GetPipelineInputsRequest\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId"\xed\x01\n\x19GetPipelineInputsResponse\x12\x1f\n\x0binput_names\x18\x01 \x03(\tR\ninputNames\x12W\n\x0binput_specs\x18\x02 \x03(\x0b\x32\x36.cuvis_ai.v1.GetPipelineInputsResponse.InputSpecsEntryR\ninputSpecs\x1aV\n\x0fInputSpecsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x17.cuvis_ai.v1.TensorSpecR\x05value:\x02\x38\x01":\n\x19GetPipelineOutputsRequest\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId"\xf5\x01\n\x1aGetPipelineOutputsResponse\x12!\n\x0coutput_names\x18\x01 \x03(\tR\x0boutputNames\x12[\n\x0coutput_specs\x18\x02 \x03(\x0b\x32\x38.cuvis_ai.v1.GetPipelineOutputsResponse.OutputSpecsEntryR\x0boutputSpecs\x1aW\n\x10OutputSpecsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x17.cuvis_ai.v1.TensorSpecR\x05value:\x02\x38\x01"X\n\x1fGetPipelineVisualizationRequest\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId\x12\x16\n\x06\x66ormat\x18\x02 \x01(\tR\x06\x66ormat"Y\n GetPipelineVisualizationResponse\x12\x1d\n\nimage_data\x18\x01 \x01(\x0cR\timageData\x12\x16\n\x06\x66ormat\x18\x02 \x01(\tR\x06\x66ormat"\x85\x01\n\x10InferenceRequest\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId\x12/\n\x06inputs\x18\x02 \x01(\x0b\x32\x17.cuvis_ai.v1.InputBatchR\x06inputs\x12!\n\x0coutput_specs\x18\x03 \x03(\tR\x0boutputSpecs"\xae\x02\n\x11InferenceResponse\x12\x45\n\x07outputs\x18\x01 \x03(\x0b\x32+.cuvis_ai.v1.InferenceResponse.OutputsEntryR\x07outputs\x12\x45\n\x07metrics\x18\x02 \x03(\x0b\x32+.cuvis_ai.v1.InferenceResponse.MetricsEntryR\x07metrics\x1aO\n\x0cOutputsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x13.cuvis_ai.v1.TensorR\x05value:\x02\x38\x01\x1a:\n\x0cMetricsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x02R\x05value:\x02\x38\x01"3\n\x0ePluginManifest\x12!\n\x0c\x63onfig_bytes\x18\x01 \x01(\x0cR\x0b\x63onfigBytes"z\n\nPluginInfo\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x16\n\x06source\x18\x03 \x01(\tR\x06source\x12\x10\n\x03tag\x18\x04 \x01(\tR\x03tag\x12\x1a\n\x08provides\x18\x05 \x03(\tR\x08provides"\x9c\x01\n\x08PortSpec\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12(\n\x05\x64type\x18\x02 \x01(\x0e\x32\x12.cuvis_ai.v1.DTypeR\x05\x64type\x12\x14\n\x05shape\x18\x03 \x03(\x03R\x05shape\x12\x1a\n\x08optional\x18\x04 \x01(\x08R\x08optional\x12 \n\x0b\x64\x65scription\x18\x05 \x01(\tR\x0b\x64\x65scription";\n\x0cPortSpecList\x12+\n\x05specs\x18\x01 \x03(\x0b\x32\x15.cuvis_ai.v1.PortSpecR\x05specs"\xc7\x03\n\x08NodeInfo\x12\x1d\n\nclass_name\x18\x01 \x01(\tR\tclassName\x12\x1b\n\tfull_path\x18\x02 \x01(\tR\x08\x66ullPath\x12\x16\n\x06source\x18\x03 \x01(\tR\x06source\x12\x1f\n\x0bplugin_name\x18\x04 \x01(\tR\npluginName\x12\x46\n\x0binput_specs\x18\x05 \x03(\x0b\x32%.cuvis_ai.v1.NodeInfo.InputSpecsEntryR\ninputSpecs\x12I\n\x0coutput_specs\x18\x06 \x03(\x0b\x32&.cuvis_ai.v1.NodeInfo.OutputSpecsEntryR\x0boutputSpecs\x1aX\n\x0fInputSpecsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12/\n\x05value\x18\x02 \x01(\x0b\x32\x19.cuvis_ai.v1.PortSpecListR\x05value:\x02\x38\x01\x1aY\n\x10OutputSpecsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12/\n\x05value\x18\x02 \x01(\x0b\x32\x19.cuvis_ai.v1.PortSpecListR\x05value:\x02\x38\x01"l\n\x12LoadPluginsRequest\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId\x12\x37\n\x08manifest\x18\x02 \x01(\x0b\x32\x1b.cuvis_ai.v1.PluginManifestR\x08manifest"\xda\x01\n\x13LoadPluginsResponse\x12%\n\x0eloaded_plugins\x18\x01 \x03(\tR\rloadedPlugins\x12Z\n\x0e\x66\x61iled_plugins\x18\x02 \x03(\x0b\x32\x33.cuvis_ai.v1.LoadPluginsResponse.FailedPluginsEntryR\rfailedPlugins\x1a@\n\x12\x46\x61iledPluginsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01"9\n\x18ListLoadedPluginsRequest\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId"N\n\x19ListLoadedPluginsResponse\x12\x31\n\x07plugins\x18\x01 \x03(\x0b\x32\x17.cuvis_ai.v1.PluginInfoR\x07plugins"V\n\x14GetPluginInfoRequest\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId\x12\x1f\n\x0bplugin_name\x18\x02 \x01(\tR\npluginName"H\n\x15GetPluginInfoResponse\x12/\n\x06plugin\x18\x01 \x01(\x0b\x32\x17.cuvis_ai.v1.PluginInfoR\x06plugin":\n\x19ListAvailableNodesRequest\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId"I\n\x1aListAvailableNodesResponse\x12+\n\x05nodes\x18\x01 \x03(\x0b\x32\x15.cuvis_ai.v1.NodeInfoR\x05nodes":\n\x17\x43learPluginCacheRequest\x12\x1f\n\x0bplugin_name\x18\x01 \x01(\tR\npluginName"?\n\x18\x43learPluginCacheResponse\x12#\n\rcleared_count\x18\x01 \x01(\x05R\x0c\x63learedCount*\xb4\x01\n\x0eProcessingMode\x12\x1f\n\x1bPROCESSING_MODE_UNSPECIFIED\x10\x00\x12\x17\n\x13PROCESSING_MODE_RAW\x10\x01\x12\x1f\n\x1bPROCESSING_MODE_REFLECTANCE\x10\x02\x12 \n\x1cPROCESSING_MODE_DARKSUBTRACT\x10\x03\x12%\n!PROCESSING_MODE_SPECTRAL_RADIANCE\x10\x04*\x9e\x01\n\x0e\x45xecutionStage\x12\x1f\n\x1b\x45XECUTION_STAGE_UNSPECIFIED\x10\x00\x12\x19\n\x15\x45XECUTION_STAGE_TRAIN\x10\x01\x12\x17\n\x13\x45XECUTION_STAGE_VAL\x10\x02\x12\x18\n\x14\x45XECUTION_STAGE_TEST\x10\x03\x12\x1d\n\x19\x45XECUTION_STAGE_INFERENCE\x10\x04*\xb5\x01\n\x05\x44Type\x12\x16\n\x12\x44_TYPE_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x44_TYPE_FLOAT32\x10\x01\x12\x12\n\x0e\x44_TYPE_FLOAT64\x10\x02\x12\x10\n\x0c\x44_TYPE_INT32\x10\x03\x12\x10\n\x0c\x44_TYPE_INT64\x10\x04\x12\x10\n\x0c\x44_TYPE_UINT8\x10\x05\x12\x0f\n\x0b\x44_TYPE_BOOL\x10\x06\x12\x12\n\x0e\x44_TYPE_FLOAT16\x10\x07\x12\x11\n\rD_TYPE_UINT16\x10\x08*d\n\x0bTrainerType\x12\x1c\n\x18TRAINER_TYPE_UNSPECIFIED\x10\x00\x12\x1c\n\x18TRAINER_TYPE_STATISTICAL\x10\x01\x12\x19\n\x15TRAINER_TYPE_GRADIENT\x10\x02*x\n\x0bTrainStatus\x12\x1c\n\x18TRAIN_STATUS_UNSPECIFIED\x10\x00\x12\x18\n\x14TRAIN_STATUS_RUNNING\x10\x01\x12\x19\n\x15TRAIN_STATUS_COMPLETE\x10\x02\x12\x16\n\x12TRAIN_STATUS_ERROR\x10\x03*q\n\tPointType\x12\x1a\n\x16POINT_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13POINT_TYPE_POSITIVE\x10\x01\x12\x17\n\x13POINT_TYPE_NEGATIVE\x10\x02\x12\x16\n\x12POINT_TYPE_NEUTRAL\x10\x03\x32\xbc\x13\n\x0e\x43uvisAIService\x12q\n\x16ListAvailablePipelines\x12*.cuvis_ai.v1.ListAvailablePipelinesRequest\x1a+.cuvis_ai.v1.ListAvailablePipelinesResponse\x12\\\n\x0fGetPipelineInfo\x12#.cuvis_ai.v1.GetPipelineInfoRequest\x1a$.cuvis_ai.v1.GetPipelineInfoResponse\x12V\n\rCreateSession\x12!.cuvis_ai.v1.CreateSessionRequest\x1a".cuvis_ai.v1.CreateSessionResponse\x12n\n\x15SetSessionSearchPaths\x12).cuvis_ai.v1.SetSessionSearchPathsRequest\x1a*.cuvis_ai.v1.SetSessionSearchPathsResponse\x12S\n\x0c\x43loseSession\x12 .cuvis_ai.v1.CloseSessionRequest\x1a!.cuvis_ai.v1.CloseSessionResponse\x12V\n\rResolveConfig\x12!.cuvis_ai.v1.ResolveConfigRequest\x1a".cuvis_ai.v1.ResolveConfigResponse\x12\x65\n\x12GetParameterSchema\x12&.cuvis_ai.v1.GetParameterSchemaRequest\x1a\'.cuvis_ai.v1.GetParameterSchemaResponse\x12Y\n\x0eValidateConfig\x12".cuvis_ai.v1.ValidateConfigRequest\x1a#.cuvis_ai.v1.ValidateConfigResponse\x12h\n\x13LoadPipelineWeights\x12\'.cuvis_ai.v1.LoadPipelineWeightsRequest\x1a(.cuvis_ai.v1.LoadPipelineWeightsResponse\x12\x62\n\x11SetTrainRunConfig\x12%.cuvis_ai.v1.SetTrainRunConfigRequest\x1a&.cuvis_ai.v1.SetTrainRunConfigResponse\x12@\n\x05Train\x12\x19.cuvis_ai.v1.TrainRequest\x1a\x1a.cuvis_ai.v1.TrainResponse0\x01\x12Y\n\x0eGetTrainStatus\x12".cuvis_ai.v1.GetTrainStatusRequest\x1a#.cuvis_ai.v1.GetTrainStatusResponse\x12t\n\x17GetTrainingCapabilities\x12+.cuvis_ai.v1.GetTrainingCapabilitiesRequest\x1a,.cuvis_ai.v1.GetTrainingCapabilitiesResponse\x12S\n\x0cSavePipeline\x12 .cuvis_ai.v1.SavePipelineRequest\x1a!.cuvis_ai.v1.SavePipelineResponse\x12S\n\x0cLoadPipeline\x12 .cuvis_ai.v1.LoadPipelineRequest\x1a!.cuvis_ai.v1.LoadPipelineResponse\x12S\n\x0cSaveTrainRun\x12 .cuvis_ai.v1.SaveTrainRunRequest\x1a!.cuvis_ai.v1.SaveTrainRunResponse\x12\\\n\x0fRestoreTrainRun\x12#.cuvis_ai.v1.RestoreTrainRunRequest\x1a$.cuvis_ai.v1.RestoreTrainRunResponse\x12\x62\n\x11GetPipelineInputs\x12%.cuvis_ai.v1.GetPipelineInputsRequest\x1a&.cuvis_ai.v1.GetPipelineInputsResponse\x12\x65\n\x12GetPipelineOutputs\x12&.cuvis_ai.v1.GetPipelineOutputsRequest\x1a\'.cuvis_ai.v1.GetPipelineOutputsResponse\x12w\n\x18GetPipelineVisualization\x12,.cuvis_ai.v1.GetPipelineVisualizationRequest\x1a-.cuvis_ai.v1.GetPipelineVisualizationResponse\x12J\n\tInference\x12\x1d.cuvis_ai.v1.InferenceRequest\x1a\x1e.cuvis_ai.v1.InferenceResponse\x12P\n\x0bLoadPlugins\x12\x1f.cuvis_ai.v1.LoadPluginsRequest\x1a .cuvis_ai.v1.LoadPluginsResponse\x12\x62\n\x11ListLoadedPlugins\x12%.cuvis_ai.v1.ListLoadedPluginsRequest\x1a&.cuvis_ai.v1.ListLoadedPluginsResponse\x12V\n\rGetPluginInfo\x12!.cuvis_ai.v1.GetPluginInfoRequest\x1a".cuvis_ai.v1.GetPluginInfoResponse\x12\x65\n\x12ListAvailableNodes\x12&.cuvis_ai.v1.ListAvailableNodesRequest\x1a\'.cuvis_ai.v1.ListAvailableNodesResponse\x12_\n\x10\x43learPluginCache\x12$.cuvis_ai.v1.ClearPluginCacheRequest\x1a%.cuvis_ai.v1.ClearPluginCacheResponseb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "cuvis_ai_schemas.grpc.v1.cuvis_ai_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals["_INPUTBATCH_EXTRAINPUTSENTRY"]._loaded_options = None
    _globals["_INPUTBATCH_EXTRAINPUTSENTRY"]._serialized_options = b"8\001"
    _globals["_TRAINRESPONSE_LOSSESENTRY"]._loaded_options = None
    _globals["_TRAINRESPONSE_LOSSESENTRY"]._serialized_options = b"8\001"
    _globals["_TRAINRESPONSE_METRICSENTRY"]._loaded_options = None
    _globals["_TRAINRESPONSE_METRICSENTRY"]._serialized_options = b"8\001"
    _globals["_GETPIPELINEINPUTSRESPONSE_INPUTSPECSENTRY"]._loaded_options = None
    _globals["_GETPIPELINEINPUTSRESPONSE_INPUTSPECSENTRY"]._serialized_options = b"8\001"
    _globals["_GETPIPELINEOUTPUTSRESPONSE_OUTPUTSPECSENTRY"]._loaded_options = None
    _globals["_GETPIPELINEOUTPUTSRESPONSE_OUTPUTSPECSENTRY"]._serialized_options = b"8\001"
    _globals["_INFERENCERESPONSE_OUTPUTSENTRY"]._loaded_options = None
    _globals["_INFERENCERESPONSE_OUTPUTSENTRY"]._serialized_options = b"8\001"
    _globals["_INFERENCERESPONSE_METRICSENTRY"]._loaded_options = None
    _globals["_INFERENCERESPONSE_METRICSENTRY"]._serialized_options = b"8\001"
    _globals["_NODEINFO_INPUTSPECSENTRY"]._loaded_options = None
    _globals["_NODEINFO_INPUTSPECSENTRY"]._serialized_options = b"8\001"
    _globals["_NODEINFO_OUTPUTSPECSENTRY"]._loaded_options = None
    _globals["_NODEINFO_OUTPUTSPECSENTRY"]._serialized_options = b"8\001"
    _globals["_LOADPLUGINSRESPONSE_FAILEDPLUGINSENTRY"]._loaded_options = None
    _globals["_LOADPLUGINSRESPONSE_FAILEDPLUGINSENTRY"]._serialized_options = b"8\001"
    _globals["_PROCESSINGMODE"]._serialized_start = 9518
    _globals["_PROCESSINGMODE"]._serialized_end = 9698
    _globals["_EXECUTIONSTAGE"]._serialized_start = 9701
    _globals["_EXECUTIONSTAGE"]._serialized_end = 9859
    _globals["_DTYPE"]._serialized_start = 9862
    _globals["_DTYPE"]._serialized_end = 10043
    _globals["_TRAINERTYPE"]._serialized_start = 10045
    _globals["_TRAINERTYPE"]._serialized_end = 10145
    _globals["_TRAINSTATUS"]._serialized_start = 10147
    _globals["_TRAINSTATUS"]._serialized_end = 10267
    _globals["_POINTTYPE"]._serialized_start = 10269
    _globals["_POINTTYPE"]._serialized_end = 10382
    _globals["_TENSOR"]._serialized_start = 56
    _globals["_TENSOR"]._serialized_end = 155
    _globals["_CONTEXT"]._serialized_start = 158
    _globals["_CONTEXT"]._serialized_end = 302
    _globals["_PIPELINECONFIG"]._serialized_start = 304
    _globals["_PIPELINECONFIG"]._serialized_end = 355
    _globals["_DATACONFIG"]._serialized_start = 357
    _globals["_DATACONFIG"]._serialized_end = 404
    _globals["_OPTIMIZERCONFIG"]._serialized_start = 406
    _globals["_OPTIMIZERCONFIG"]._serialized_end = 458
    _globals["_SCHEDULERCONFIG"]._serialized_start = 460
    _globals["_SCHEDULERCONFIG"]._serialized_end = 512
    _globals["_CALLBACKSCONFIG"]._serialized_start = 514
    _globals["_CALLBACKSCONFIG"]._serialized_end = 566
    _globals["_PIPELINEMETADATA"]._serialized_start = 569
    _globals["_PIPELINEMETADATA"]._serialized_end = 753
    _globals["_PIPELINEINFO"]._serialized_start = 756
    _globals["_PIPELINEINFO"]._serialized_end = 992
    _globals["_TRAININGCONFIG"]._serialized_start = 994
    _globals["_TRAININGCONFIG"]._serialized_end = 1045
    _globals["_TRAINRUNCONFIG"]._serialized_start = 1047
    _globals["_TRAINRUNCONFIG"]._serialized_end = 1098
    _globals["_BOUNDINGBOX"]._serialized_start = 1101
    _globals["_BOUNDINGBOX"]._serialized_end = 1229
    _globals["_BOUNDINGBOXES"]._serialized_start = 1231
    _globals["_BOUNDINGBOXES"]._serialized_end = 1294
    _globals["_POINT"]._serialized_start = 1296
    _globals["_POINT"]._serialized_end = 1406
    _globals["_POINTS"]._serialized_start = 1408
    _globals["_POINTS"]._serialized_end = 1460
    _globals["_INPUTBATCH"]._serialized_start = 1463
    _globals["_INPUTBATCH"]._serialized_end = 1904
    _globals["_INPUTBATCH_EXTRAINPUTSENTRY"]._serialized_start = 1821
    _globals["_INPUTBATCH_EXTRAINPUTSENTRY"]._serialized_end = 1904
    _globals["_TENSORSPEC"]._serialized_start = 1906
    _globals["_TENSORSPEC"]._serialized_end = 2030
    _globals["_TRAINRESPONSE"]._serialized_start = 2033
    _globals["_TRAINRESPONSE"]._serialized_end = 2422
    _globals["_TRAINRESPONSE_LOSSESENTRY"]._serialized_start = 2305
    _globals["_TRAINRESPONSE_LOSSESENTRY"]._serialized_end = 2362
    _globals["_TRAINRESPONSE_METRICSENTRY"]._serialized_start = 2364
    _globals["_TRAINRESPONSE_METRICSENTRY"]._serialized_end = 2422
    _globals["_PARAMSPEC"]._serialized_start = 2425
    _globals["_PARAMSPEC"]._serialized_end = 2607
    _globals["_CALLBACKTYPEINFO"]._serialized_start = 2610
    _globals["_CALLBACKTYPEINFO"]._serialized_end = 2738
    _globals["_OPTIMIZERPARAMSSCHEMA"]._serialized_start = 2740
    _globals["_OPTIMIZERPARAMSSCHEMA"]._serialized_end = 2819
    _globals["_SCHEDULERPARAMSSCHEMA"]._serialized_start = 2821
    _globals["_SCHEDULERPARAMSSCHEMA"]._serialized_end = 2900
    _globals["_LISTAVAILABLEPIPELINESREQUEST"]._serialized_start = 2902
    _globals["_LISTAVAILABLEPIPELINESREQUEST"]._serialized_end = 2984
    _globals["_LISTAVAILABLEPIPELINESRESPONSE"]._serialized_start = 2986
    _globals["_LISTAVAILABLEPIPELINESRESPONSE"]._serialized_end = 3075
    _globals["_GETPIPELINEINFOREQUEST"]._serialized_start = 3077
    _globals["_GETPIPELINEINFOREQUEST"]._serialized_end = 3138
    _globals["_GETPIPELINEINFORESPONSE"]._serialized_start = 3140
    _globals["_GETPIPELINEINFORESPONSE"]._serialized_end = 3229
    _globals["_CREATESESSIONREQUEST"]._serialized_start = 3231
    _globals["_CREATESESSIONREQUEST"]._serialized_end = 3253
    _globals["_CREATESESSIONRESPONSE"]._serialized_start = 3255
    _globals["_CREATESESSIONRESPONSE"]._serialized_end = 3309
    _globals["_SETSESSIONSEARCHPATHSREQUEST"]._serialized_start = 3312
    _globals["_SETSESSIONSEARCHPATHSREQUEST"]._serialized_end = 3448
    _globals["_SETSESSIONSEARCHPATHSRESPONSE"]._serialized_start = 3451
    _globals["_SETSESSIONSEARCHPATHSRESPONSE"]._serialized_end = 3584
    _globals["_CLOSESESSIONREQUEST"]._serialized_start = 3586
    _globals["_CLOSESESSIONREQUEST"]._serialized_end = 3638
    _globals["_CLOSESESSIONRESPONSE"]._serialized_start = 3640
    _globals["_CLOSESESSIONRESPONSE"]._serialized_end = 3688
    _globals["_RESOLVECONFIGREQUEST"]._serialized_start = 3691
    _globals["_RESOLVECONFIGREQUEST"]._serialized_end = 3827
    _globals["_RESOLVECONFIGRESPONSE"]._serialized_start = 3829
    _globals["_RESOLVECONFIGRESPONSE"]._serialized_end = 3887
    _globals["_GETPARAMETERSCHEMAREQUEST"]._serialized_start = 3889
    _globals["_GETPARAMETERSCHEMAREQUEST"]._serialized_end = 3949
    _globals["_GETPARAMETERSCHEMARESPONSE"]._serialized_start = 3951
    _globals["_GETPARAMETERSCHEMARESPONSE"]._serialized_end = 4012
    _globals["_VALIDATECONFIGREQUEST"]._serialized_start = 4014
    _globals["_VALIDATECONFIGREQUEST"]._serialized_end = 4105
    _globals["_VALIDATECONFIGRESPONSE"]._serialized_start = 4107
    _globals["_VALIDATECONFIGRESPONSE"]._serialized_end = 4205
    _globals["_LOADPIPELINEWEIGHTSREQUEST"]._serialized_start = 4208
    _globals["_LOADPIPELINEWEIGHTSREQUEST"]._serialized_end = 4401
    _globals["_LOADPIPELINEWEIGHTSRESPONSE"]._serialized_start = 4403
    _globals["_LOADPIPELINEWEIGHTSRESPONSE"]._serialized_end = 4495
    _globals["_SETTRAINRUNCONFIGREQUEST"]._serialized_start = 4497
    _globals["_SETTRAINRUNCONFIGREQUEST"]._serialized_end = 4607
    _globals["_SETTRAINRUNCONFIGRESPONSE"]._serialized_start = 4609
    _globals["_SETTRAINRUNCONFIGRESPONSE"]._serialized_end = 4712
    _globals["_TRAINREQUEST"]._serialized_start = 4715
    _globals["_TRAINREQUEST"]._serialized_end = 4923
    _globals["_GETTRAINSTATUSREQUEST"]._serialized_start = 4925
    _globals["_GETTRAINSTATUSREQUEST"]._serialized_end = 4979
    _globals["_GETTRAINSTATUSRESPONSE"]._serialized_start = 4981
    _globals["_GETTRAINSTATUSRESPONSE"]._serialized_end = 5074
    _globals["_GETTRAININGCAPABILITIESREQUEST"]._serialized_start = 5076
    _globals["_GETTRAININGCAPABILITIESREQUEST"]._serialized_end = 5108
    _globals["_GETTRAININGCAPABILITIESRESPONSE"]._serialized_start = 5111
    _globals["_GETTRAININGCAPABILITIESRESPONSE"]._serialized_end = 5484
    _globals["_SAVEPIPELINEREQUEST"]._serialized_start = 5487
    _globals["_SAVEPIPELINEREQUEST"]._serialized_end = 5635
    _globals["_SAVEPIPELINERESPONSE"]._serialized_start = 5637
    _globals["_SAVEPIPELINERESPONSE"]._serialized_end = 5757
    _globals["_LOADPIPELINEREQUEST"]._serialized_start = 5759
    _globals["_LOADPIPELINEREQUEST"]._serialized_end = 5868
    _globals["_LOADPIPELINERESPONSE"]._serialized_start = 5870
    _globals["_LOADPIPELINERESPONSE"]._serialized_end = 5977
    _globals["_SAVETRAINRUNREQUEST"]._serialized_start = 5979
    _globals["_SAVETRAINRUNREQUEST"]._serialized_end = 6103
    _globals["_SAVETRAINRUNRESPONSE"]._serialized_start = 6106
    _globals["_SAVETRAINRUNRESPONSE"]._serialized_end = 6263
    _globals["_RESTORETRAINRUNREQUEST"]._serialized_start = 6266
    _globals["_RESTORETRAINRUNREQUEST"]._serialized_end = 6424
    _globals["_RESTORETRAINRUNRESPONSE"]._serialized_start = 6426
    _globals["_RESTORETRAINRUNRESPONSE"]._serialized_end = 6539
    _globals["_GETPIPELINEINPUTSREQUEST"]._serialized_start = 6541
    _globals["_GETPIPELINEINPUTSREQUEST"]._serialized_end = 6598
    _globals["_GETPIPELINEINPUTSRESPONSE"]._serialized_start = 6601
    _globals["_GETPIPELINEINPUTSRESPONSE"]._serialized_end = 6838
    _globals["_GETPIPELINEINPUTSRESPONSE_INPUTSPECSENTRY"]._serialized_start = 6752
    _globals["_GETPIPELINEINPUTSRESPONSE_INPUTSPECSENTRY"]._serialized_end = 6838
    _globals["_GETPIPELINEOUTPUTSREQUEST"]._serialized_start = 6840
    _globals["_GETPIPELINEOUTPUTSREQUEST"]._serialized_end = 6898
    _globals["_GETPIPELINEOUTPUTSRESPONSE"]._serialized_start = 6901
    _globals["_GETPIPELINEOUTPUTSRESPONSE"]._serialized_end = 7146
    _globals["_GETPIPELINEOUTPUTSRESPONSE_OUTPUTSPECSENTRY"]._serialized_start = 7059
    _globals["_GETPIPELINEOUTPUTSRESPONSE_OUTPUTSPECSENTRY"]._serialized_end = 7146
    _globals["_GETPIPELINEVISUALIZATIONREQUEST"]._serialized_start = 7148
    _globals["_GETPIPELINEVISUALIZATIONREQUEST"]._serialized_end = 7236
    _globals["_GETPIPELINEVISUALIZATIONRESPONSE"]._serialized_start = 7238
    _globals["_GETPIPELINEVISUALIZATIONRESPONSE"]._serialized_end = 7327
    _globals["_INFERENCEREQUEST"]._serialized_start = 7330
    _globals["_INFERENCEREQUEST"]._serialized_end = 7463
    _globals["_INFERENCERESPONSE"]._serialized_start = 7466
    _globals["_INFERENCERESPONSE"]._serialized_end = 7768
    _globals["_INFERENCERESPONSE_OUTPUTSENTRY"]._serialized_start = 7629
    _globals["_INFERENCERESPONSE_OUTPUTSENTRY"]._serialized_end = 7708
    _globals["_INFERENCERESPONSE_METRICSENTRY"]._serialized_start = 2364
    _globals["_INFERENCERESPONSE_METRICSENTRY"]._serialized_end = 2422
    _globals["_PLUGINMANIFEST"]._serialized_start = 7770
    _globals["_PLUGINMANIFEST"]._serialized_end = 7821
    _globals["_PLUGININFO"]._serialized_start = 7823
    _globals["_PLUGININFO"]._serialized_end = 7945
    _globals["_PORTSPEC"]._serialized_start = 7948
    _globals["_PORTSPEC"]._serialized_end = 8104
    _globals["_PORTSPECLIST"]._serialized_start = 8106
    _globals["_PORTSPECLIST"]._serialized_end = 8165
    _globals["_NODEINFO"]._serialized_start = 8168
    _globals["_NODEINFO"]._serialized_end = 8623
    _globals["_NODEINFO_INPUTSPECSENTRY"]._serialized_start = 8444
    _globals["_NODEINFO_INPUTSPECSENTRY"]._serialized_end = 8532
    _globals["_NODEINFO_OUTPUTSPECSENTRY"]._serialized_start = 8534
    _globals["_NODEINFO_OUTPUTSPECSENTRY"]._serialized_end = 8623
    _globals["_LOADPLUGINSREQUEST"]._serialized_start = 8625
    _globals["_LOADPLUGINSREQUEST"]._serialized_end = 8733
    _globals["_LOADPLUGINSRESPONSE"]._serialized_start = 8736
    _globals["_LOADPLUGINSRESPONSE"]._serialized_end = 8954
    _globals["_LOADPLUGINSRESPONSE_FAILEDPLUGINSENTRY"]._serialized_start = 8890
    _globals["_LOADPLUGINSRESPONSE_FAILEDPLUGINSENTRY"]._serialized_end = 8954
    _globals["_LISTLOADEDPLUGINSREQUEST"]._serialized_start = 8956
    _globals["_LISTLOADEDPLUGINSREQUEST"]._serialized_end = 9013
    _globals["_LISTLOADEDPLUGINSRESPONSE"]._serialized_start = 9015
    _globals["_LISTLOADEDPLUGINSRESPONSE"]._serialized_end = 9093
    _globals["_GETPLUGININFOREQUEST"]._serialized_start = 9095
    _globals["_GETPLUGININFOREQUEST"]._serialized_end = 9181
    _globals["_GETPLUGININFORESPONSE"]._serialized_start = 9183
    _globals["_GETPLUGININFORESPONSE"]._serialized_end = 9255
    _globals["_LISTAVAILABLENODESREQUEST"]._serialized_start = 9257
    _globals["_LISTAVAILABLENODESREQUEST"]._serialized_end = 9315
    _globals["_LISTAVAILABLENODESRESPONSE"]._serialized_start = 9317
    _globals["_LISTAVAILABLENODESRESPONSE"]._serialized_end = 9390
    _globals["_CLEARPLUGINCACHEREQUEST"]._serialized_start = 9392
    _globals["_CLEARPLUGINCACHEREQUEST"]._serialized_end = 9450
    _globals["_CLEARPLUGINCACHERESPONSE"]._serialized_start = 9452
    _globals["_CLEARPLUGINCACHERESPONSE"]._serialized_end = 9515
    _globals["_CUVISAISERVICE"]._serialized_start = 10385
    _globals["_CUVISAISERVICE"]._serialized_end = 12877
# @@protoc_insertion_point(module_scope)
